# AdviserResultResponseResultReportProducts

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**advised_manifest_changes** | **list[list[object]]** | Advised changes to manifest files |
**advised_runtime_environment** | [**RuntimeEnvironment**](RuntimeEnvironment.md) |  |
**dependency_graph** | [**AdviserResultResponseResultReportDependencyGraph**](AdviserResultResponseResultReportDependencyGraph.md) |  |
**justification** | [**Justification**](Justification.md) |  |
**project** | [**ProjectDef**](ProjectDef.md) |  |
**score** | **float** | Score of the computed product |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

